Installation Requirements
=========================

Please use Python 3.6.0 for the project interpreter.
https://www.python.org/downloads/release/python-360/


Please install the following packages to use OMEGAlpes:

.. contents::
    :depth: 1
    :local:
    :backlinks: top

Help for library installation:

Command lover::

    pip install <library_name>==version

If required, the command to upgrade the library is ::

    pip install --upgrade <library_name>

Pycharm lover:

Install automatically the library using pip with Pycharm on "File", "settings...", "Project Interpreter", "+",
and choosing the required library



PuLP >= 1.6.8
-------------
PuLP is an LP modeler written in python. PuLP can generate MPS or LP files and call GLPK, COIN CLP/CBC, CPLEX, and GUROBI to solve linear problems.
https://github.com/coin-or/pulp

Matplotlib >= 2.2.2, <3.1
-------------------------
Matplotlib is a Python 2D plotting library.
https://matplotlib.org/

Numpy >= 1.14.2, <1.16
----------------------
NumPy is the fundamental package needed for scientific computing with Python.
https://github.com/numpy/numpy

Pandas >= 0.22.0, <0.24
-----------------------
pandas is a Python package providing fast, flexible, and expressive data structures designed to make working with "relational" or "labeled" data both easy and intuitive.
https://pandas.pydata.org/pandas-docs/version/0.23.1/index.html